@@ -244,21 +244,21 @@ def terp_survey():
 	return True
 
 
-def file_selection(title, filename='', parent=None,
-		action=gtk.FILE_CHOOSER_ACTION_OPEN, preview=True, multi=False, filters=None):
+def file_selection(title, filename='', parent=None, action=gtk.FILE_CHOOSER_ACTION_OPEN, preview=True, multi=False, filters=None):
 	if action == gtk.FILE_CHOOSER_ACTION_OPEN:
-		buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-			gtk.STOCK_OPEN,gtk.RESPONSE_OK)
+		buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OPEN, gtk.RESPONSE_OK)
 	else:
-		buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-			gtk.STOCK_SAVE, gtk.RESPONSE_OK)
+		buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_SAVE, gtk.RESPONSE_OK)
 	win = gtk.FileChooserDialog(title, None, action, buttons)
 	if parent:
 		win.set_transient_for(parent)
 	win.set_icon(TINYERP_ICON)
-	win.set_current_folder(options.options['client.default_path'])
+	
+	client_default_path = options.options['client.default_path']
+	win.set_current_folder(client_default_path)
 	if filename:
-		win.set_filename(os.path.join(options.options['client.default_path'], filename))
+		win.set_current_name(filename)
+
 	win.set_select_multiple(multi)
 	win.set_default_response(gtk.RESPONSE_OK)
 	if filters is not None:
