@@ -36,6 +36,8 @@ import printer
 
 import common
 import tools
+from widget.screen import Screen
+from widget.view.form_gtk.many2one import dialog
 
 class main(service.Service):
 	def __init__(self, name='action.main'):
@@ -113,7 +115,11 @@ class main(service.Service):
 
 			if datas.get('domain', False):
 				domain.append(datas['domain'])
-
+			if 'target' in action:
+				if action['target']=='new':
+					dia = dialog(datas['res_model'],window=datas.get('window',None), domain=domain, context=ctx)
+					ok, value = dia.run()
+					dia.destroy()
 			obj = service.LocalService('gui.window')
 			obj.create(view_ids, datas['res_model'], datas['res_id'], domain,
 					action['view_type'], datas.get('window',None), ctx,
