@@ -3,7 +3,7 @@
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #					Fabien Pinckaers <fp@tiny.Be>
 #
-# $Id: main.py 7846 2007-10-26 07:58:44Z ced $
+# $Id$
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -43,7 +43,7 @@ import service
 import options
 import common
 
-from window import win_preference
+from window import win_preference, win_extension
 import tools
 import re
 import xmlrpclib
@@ -481,6 +481,7 @@ class terp_main(service.Service):
 			'on_db_backup_activate': self.sig_db_dump,
 			'on_db_drop_activate': self.sig_db_drop,
 			'on_admin_password_activate': self.sig_db_password,
+			'on_extension_manager_activate': self.sig_extension_manager, 
 		}
 		for signal in dict:
 			self.glade.signal_connect(signal, dict[signal])
@@ -950,6 +951,10 @@ class terp_main(service.Service):
 				else:
 					common.warning(_("Couldn't restore database"), parent=self.window)
 
+	def sig_extension_manager(self,widget):
+		win = win_extension.win_extension(self.window)
+		win.run()
+
 	def sig_db_password(self, widget):
 		dialog = glade.XML(common.terp_path("terp.glade"), "dia_passwd_change",
 				gettext.textdomain())
