@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 name = 'tinyerp-client'
-version = '4.2.2'
+version = '4.2.3.4'
 description = 'Tiny\'s ERP Client'
 long_desc = '''\
 Tiny ERP is a complete ERP and CRM. The main features are accounting (analytic
@@ -15,7 +15,7 @@ Development Status :: 5 - Production/Stable
 License :: OSI Approved :: GNU General Public License Version 2 (GPL-2)
 Programming Language :: Python
 """
-url = 'http://www.tinyerp.com'
+url = 'http://www.openerp.com'
 author = 'Tiny.be'
 author_email = 'info@tiny.be'
 license = 'GPL-2'
