@@ -44,14 +44,21 @@ def launch_browser(url):
 	else:
 		pid = os.fork()
 		if not pid:
-			webbrowser.open(url)
-			sys.exit()
+			pid = os.fork()
+			if not pid:
+				webbrowser.open(url)
+			sys.exit(0)
+		os.wait()
 
 def node_attributes(node):
-   result = {}
-   attrs = node.attributes
-   if attrs is None:
-	   return {}
-   for i in range(attrs.length):
-		   result[attrs.item(i).localName] = attrs.item(i).nodeValue
-   return result
+	result = {}
+	attrs = node.attributes
+	if attrs is None:
+		return {}
+	for i in range(attrs.length):
+		result[attrs.item(i).localName] = str(attrs.item(i).nodeValue)
+		if attrs.item(i).localName == "digits" and isinstance(attrs.item(i).nodeValue, (str, unicode)):
+			result[attrs.item(i).localName] = eval(attrs.item(i).nodeValue)
+	return result
+
+
