@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: field.py 7882 2007-10-31 15:12:59Z ced $
+# $Id$
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -29,6 +29,8 @@
 
 from rpc import RPCProxy
 import rpc
+
+
 try:
 	from sets import Set as set
 except ImportError:
@@ -41,7 +43,6 @@ class ModelField(object):
 	set: save the value from the server
 	set_client: save the value from the widget
 	'''
-
 	def __new__(cls, type):
 		klass = TYPES.get(type, CharField)
 		return klass
@@ -127,7 +128,7 @@ class CharField(object):
 				self.get_state_attrs(model)[key] = self.attrs[key]
 		if 'value' in state_changes:
 			self.set(model, value, test_state=False, modified=True)
-	
+
 	def get_state_attrs(self, model):
 		if self.name not in model.state_attrs:
 			model.state_attrs[self.name] = self.attrs.copy()
@@ -153,6 +154,20 @@ class FloatField(CharField):
 				self.sig_changed(model)
 				model.signal('record-changed', model)
 
+class BinaryField(CharField):
+	def get(self, model, check_load=True, readonly=True, modified=False):
+		if self.name in model.value:
+			if (model.value[self.name] is None) and (model.id):
+				model.value[self.name] = model.rpc.read([model.id], [self.name], rpc.session.context)[0][self.name]
+		return model.value.get(self.name, False)
+
+	def get_client(self, model):
+		print 'BINARY GET CLIENT', self.parent, model
+		if self.name in model.value:
+			if (model.value[self.name] is None) and (model.id):
+				model.value[self.name] = model.rpc.read([model.id], [self.name], rpc.session.context)[0][self.name]
+		return model.value.get(self.name, False)
+
 class IntegerField(CharField):
 
 	def get(self, model, check_load=True, readonly=True, modified=False):
@@ -397,6 +412,8 @@ TYPES = {
 	'reference' : ReferenceField,
 	'selection': SelectionField,
 	'boolean': IntegerField,
+	'image': BinaryField,
+	'binary': BinaryField,
 }
 
 # vim:noexpandtab:
