@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: many2one.py 7890 2007-10-31 15:13:31Z ced $
+# $Id$
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -244,7 +244,8 @@ class many2one(interface.widget_interface):
 		if value:
 			if not leave:
 				domain = self._view.modelfield.domain_get(self._view.model)
-				dia = dialog(self.attrs['relation'], self._view.modelfield.get(self._view.model), attrs=self.attrs, window=self._window, domain=domain)
+				context = self._view.modelfield.context_get(self._view.model)
+				dia = dialog(self.attrs['relation'], self._view.modelfield.get(self._view.model), attrs=self.attrs, window=self._window, domain=domain, context=context)
 				ok, value = dia.run()
 				if ok:
 					self._view.modelfield.set_client(self._view.model, value,
@@ -278,7 +279,8 @@ class many2one(interface.widget_interface):
 	def sig_new(self, *args):
 		self.wid_text.disconnect(self.wid_text_focus_out_id)
 		domain = self._view.modelfield.domain_get(self._view.model)
-		dia = dialog(self.attrs['relation'], attrs=self.attrs, window=self._window, domain=domain)
+		context = self._view.modelfield.context_get(self._view.model)
+		dia = dialog(self.attrs['relation'], attrs=self.attrs, window=self._window, domain=domain, context=context)
 		ok, value = dia.run()
 		if ok:
 			self._view.modelfield.set_client(self._view.model, value)
