@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: one2many_list.py 7940 2007-11-21 07:58:32Z ced $
+# $Id$
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -42,7 +42,7 @@ import service
 
 class dialog(object):
 	def __init__(self, model_name, parent, model=None, attrs=None, model_ctx=None,
-			window=None, default_get_ctx=None):
+			window=None, default_get_ctx=None, readonly=False):
 
 		if attrs is None:
 			attrs = {}
@@ -85,7 +85,7 @@ class dialog(object):
 		vp.set_shadow_type(gtk.SHADOW_NONE)
 		scroll.add(vp)
 
-		self.screen = Screen(model_name, view_type=[], parent=parent, window=self.dia)
+		self.screen = Screen(model_name, view_type=[], parent=parent, window=self.dia, readonly=False)
 		self.screen.models._context.update(model_ctx)
 		if not model:
 			model = self.screen.new(context=default_get_ctx)
@@ -158,6 +158,7 @@ class one2many_list(interface.widget_interface):
 
 		menubar.add(menuitem_title)
 		hb.pack_start(menubar, expand=True, fill=True)
+		self.ro = False
 
 		tooltips = gtk.Tooltips()
 
@@ -231,7 +232,7 @@ class one2many_list(interface.widget_interface):
 		tooltips.enable()
 		self.widget.pack_start(hb, expand=False, fill=True)
 
-		self.screen = Screen(attrs['relation'], view_type=attrs.get('mode','tree,form').split(','), parent=self.parent, views_preload=attrs.get('views', {}), tree_saves=attrs.get('saves', False), create_new=True, row_activate=self._on_activate, default_get=attrs.get('default_get', {}), window=self._window)
+		self.screen = Screen(attrs['relation'], view_type=attrs.get('mode','tree,form').split(','), parent=self.parent, views_preload=attrs.get('views', {}), tree_saves=attrs.get('saves', False), create_new=True, row_activate=self._on_activate, default_get=attrs.get('default_get', {}), window=self._window, readonly=self.ro)
 		self.screen.signal_connect(self, 'record-message', self._sig_label)
 		menuitem_title.get_child().set_text(self.screen.current_view.title)
 
@@ -270,6 +271,7 @@ class one2many_list(interface.widget_interface):
 		self.screen.switch_view()
 
 	def _readonly_set(self, value):
+		self.ro = value
 		self.eb_new.set_sensitive(not value)
 		self.eb_del.set_sensitive(not value)
 
@@ -280,10 +282,12 @@ class one2many_list(interface.widget_interface):
 		if event.type in (gtk.gdk.BUTTON_PRESS, gtk.gdk.KEY_PRESS):
 			if (self.screen.current_view.view_type=='form') or self.screen.editable_get():
 				self.screen.new(context=ctx)
+				self.ro = False
 				self.screen.current_view.widget.set_sensitive(True)
 			else:
 				ok = 1
-				dia = dialog(self.attrs['relation'], parent=self._view.model, attrs=self.attrs, model_ctx=self.screen.models._context, default_get_ctx=ctx, window=self._window)
+				readonly = self.ro
+				dia = dialog(self.attrs['relation'], parent=self._view.model, attrs=self.attrs, model_ctx=self.screen.models._context, default_get_ctx=ctx, window=self._window, readonly=readonly)
 				while ok:
 					ok, value = dia.run()
 					if ok:
@@ -295,7 +299,8 @@ class one2many_list(interface.widget_interface):
 
 	def _sig_edit(self, *args):
 		if self.screen.current_model:
-			dia = dialog(self.attrs['relation'], parent=self._view.model,  model=self.screen.current_model, attrs=self.attrs, window=self._window)
+			readonly = self.ro
+			dia = dialog(self.attrs['relation'], parent=self._view.model,  model=self.screen.current_model, attrs=self.attrs, window=self._window, readonly=readonly)
 			ok, value = dia.run()
 			dia.destroy()
 
