@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: parser.py 8235 2008-01-29 16:27:34Z ced $
+# $Id$
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -311,6 +311,10 @@ class parser_form(widget.view.interface.parser_interface):
 				fields[name]['name'] = name
 				if 'saves' in attrs:
 					fields[name]['saves'] = attrs['saves']
+
+				if 'filename' in attrs:
+				    fields[name]['filename'] = attrs['filename']
+
 				widget_act = widgets_type[type][0](self.window, self.parent, model, fields[name])
 				label = None
 				if not int(attrs.get('nolabel', 0)):
